searchNodes=[{"doc":"ExZample is a factory library based on Elixir behaviours.","ref":"ExZample.html","title":"ExZample","type":"behaviour"},{"doc":"Builds a struct with given factory module. If the given factory exports the example/0 function it will use to return the struct and its values. Otherwise, if the module is a struct it will use its default values. If will override the generated data with the given attrs. Examples iex&gt; ExZample.build(User) %ExZample.User{} iex&gt; ExZample.build(Factories.User) %ExZample.User{age: 21, email: &quot;test@test.test&quot;, first_name: &quot;First Name&quot;, id: 1, last_name: &quot;Last Name&quot;} iex&gt; ExZample.build(User, age: 45) %ExZample.User{age: 45} iex&gt; ExZample.build(Factories.User, age: 45) %ExZample.User{age: 45, email: &quot;test@test.test&quot;, first_name: &quot;First Name&quot;, id: 1, last_name: &quot;Last Name&quot;}","ref":"ExZample.html#build/2","title":"ExZample.build/2","type":"function"},{"doc":"Same as build/2, but returns a list with where the size is the given count. Examples iex&gt; ExZample.build_list(3, User) [%ExZample.User{}, %ExZample.User{}, %ExZample.User{}] iex&gt; ExZample.build_list(3, User, age: 45) [%ExZample.User{age: 45}, %ExZample.User{age: 45}, %ExZample.User{age: 45}]","ref":"ExZample.html#build_list/3","title":"ExZample.build_list/3","type":"function"},{"doc":"Same as build/2, but returns a tuple with a pair of structs. Examples iex&gt; ExZample.build_pair(User) {%ExZample.User{}, %ExZample.User{}} iex&gt; ExZample.build_pair(User, age: 45) {%ExZample.User{age: 45}, %ExZample.User{age: 45}}","ref":"ExZample.html#build_pair/2","title":"ExZample.build_pair/2","type":"function"},{"doc":"Invoked every time you build your data using ExZample module. You need to return a struct with example values. This callback is optional when the module given is a struct. It will use the struct default values if no callback is given.","ref":"ExZample.html#c:example/0","title":"ExZample.example/0","type":"callback"},{"doc":"","ref":"ExZample.html#t:factory/0","title":"ExZample.factory/0","type":"type"},{"doc":"ExZample A scalable error-friendly factories library for your Elixir apps","ref":"readme.html","title":"ExZample","type":"extras"},{"doc":"If available in Hex, the package can be installed by adding ex_zample to your list of dependencies in mix.exs: def deps do [ {:ex_zample, &quot;~&gt; 0.2.0&quot;} ] end Documentation can be generated with ExDoc and published on HexDocs. Once published, the docs can be found at https://hexdocs.pm/ex_zample.","ref":"readme.html#installation","title":"ExZample - Installation","type":"extras"},{"doc":"You can build any struct by passing a struct module: iex&gt; ExZample.build(User) %MyApp.User{first_name: nil, age: 21} ExZample will automatically use the default values inside of that struct. If you want to define different values, you need to implement the example/0 callback. defmodule MyApp.User do @behaviour ExZample defstruct first_name: nil, age: 21 @impl true def example do %__MODULE__{first_name: &quot;Abili De Bob&quot;, age: 12} end end iex&gt; ExZample.build(MyApp.User) %MyApp.User{first_name: &quot;Abili De Bob&quot;, age: 12} If you don&#39;t want to mix your test data with your app code, you can define the factory in a different module: defmodule MyApp.User do defstruct first_name: nil, age: 21 end defmodule MyApp.Factories.UserFactory do @behaviour ExZample alias MyApp.User @impl true def example do %User{first_name: &quot;Abili De Bob&quot;, age: 12} end end iex&gt; alias MyApp.Factories.UserFactory iex&gt; ExZample.build(UserFactory) %MyApp.User{first_name: &quot;Abili De Bob&quot;, age: 12}","ref":"readme.html#quick-start","title":"ExZample - Quick Start","type":"extras"},{"doc":"You can use the build/2, build_pair/2 and build_list/3 to generate data without side-effects. iex&gt; ExZample.build(UserFactory, age: 42) %MyApp.User{first_name: &quot;Abili De Bob&quot;, age: 42} iex&gt; ExZample.build_pair(UserFactory, age: 42) {%MyApp.User{first_name: &quot;Abili De Bob&quot;, age: 42}, %MyApp.User{first_name: &quot;Abili De Bob&quot;, age: 42}} iex&gt; ExZample.build_list(100, UserFactory, age: 42) [ %MyApp.User{first_name: &quot;Abili De Bob&quot;, age: 42}, %MyApp.User{first_name: &quot;Abili De Bob&quot;, age: 42}, # ... ] When you pass attributes, it will override the default ones defined in your factories.","ref":"readme.html#building-your-factories","title":"ExZample - Building your factories","type":"extras"},{"doc":"This library was strongly inspired by: ExMachina FactoryBot","ref":"readme.html#inspiration","title":"ExZample - Inspiration","type":"extras"},{"doc":"Right now you shouldn&#39;t change for this one. The other factories libraries has much more features. However, when your codebase starts to get bigger, it&#39;s nice to have a way to split up your factories files in multiple files. Also, it&#39;s important when a error happens, it should be explicit and easy to reason about. Most of other Elixir libraries relies on DLS with macro code, and you need to write macros to split up your factories files. When you get some error in your factory, it&#39;s very hard to locate where is the real problem. This library approach is to rely on vanilla Elixir modules and contracts based on Elixir behaviours. No need to use any macro. The purpose for any macro that can shows up here will be for syntax sugar, not part of the main functionality.","ref":"readme.html#why-not-other-factories-libraries","title":"ExZample - Why not other factories libraries?","type":"extras"},{"doc":"Probably not, you can define your own modules to return example structs and insert them with your repo module. However, a factory library can give you some convenient functions for you don&#39;t need to reinvent the wheel.","ref":"readme.html#do-i-really-need-a-factory-library","title":"ExZample - Do I really need a factory library?","type":"extras"}]